# Environ
Environ is a **python** framework built for you to manage your project in a few clicks, it creates an integrated file environment so your project can be awesome, a shell called EnvironShell which you can use to manage your project ALL IN ONE!


How to access environshell:
` python -m environ shell `


A few EnvironShell commands:
` help `,
` crfile [FILENAME] [CONTENTS] `
"Contents can contain \n to declare newlines"

LAST_CHANGELOG:
* Fixed Dependecy Version Error
* Added License
* Added EnvironShell access point
* Fixed Fetching version



*DISCLAIMER: SOME SYNTAX IN ERROR TRACEBACK DISRUPTED DUE TO MARKDOWN*


CHANGELOG 0.0.4:
 * fixed some errors with imports inside files

CHANGELOG 0.0.5:
 * Possibly Fixed problems with code


CHANGELOG 0.0.6:
 * Fixed Huge error with code

CHANGELOG 0.0.7:
* JUST SOME DEBUGGING

**NOTE: we are so sorry, our code had many flaws that stopped the functionality of the entire module**